==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/ja.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU情報が利用できません",
    "Load average" : "ロードアベレージ",
    "Last minute" : "直近",
    "Memory info not available" : "メモリ情報が利用できません",
    "Total" : "合計",
    "Current usage" : "現在の利用量",
    "Users" : "ユーザー",
    "Groups" : "グループ",
    "Links" : "リンク",
    "Mails" : "メール",
    "Federated sent" : "統合送信",
    "Federated received" : "統合受信",
    "Talk conversations" : "会話",
    "24 hours" : "24時間",
    "1 hour" : "1時間",
    "5 mins" : "5分",
    "Copy" : "コピー",
    "Copied!" : "コピー完了",
    "Not supported!" : "未対応",
    "Press ⌘-C to copy." : "⌘-C でコピーします。",
    "Press Ctrl-C to copy." : "Ctrl-Cを押してコピーします。",
    "System" : "システム",
    "Monitoring" : "モニタリング",
    "Monitoring app with useful server information" : "有用なサーバー情報でアプリケーションを監視する",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "CPU負荷、メモリ使用量、ディスク使用量、ユーザー数などの役に立つサーバー情報を提供します。",
    "Operating System" : "オペレーティングシステム",
    "CPU" : "CPU",
    "Memory" : "メモリ",
    "Server time" : "サーバ時間",
    "Uptime" : "稼働時間",
    "Time Servers" : "タイムサーバ",
    "Load" : "負荷",
    "Disk" : "ディスク",
    "Mount" : "マウント",
    "Filesystem" : "ファイルシステム",
    "Size" : "サイズ",
    "Available" : "利用可能",
    "Used" : "使用中",
    "You will get a notification once one of your disks is nearly full." : "いずれかのディスクがいっぱいになると通知を受け取ります。",
    "Files:" : "ファイル数:",
    "Storages:" : "ストレージ：",
    "Free Space:" : "空き容量：",
    "Network" : "ネットワーク",
    "Hostname" : "ホスト名",
    "DNS" : "DNS",
    "Gateway" : "ゲートウェイ",
    "Status" : "ステータス",
    "Speed" : "スピード",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "アクティブユーザー数",
    "Total users:" : "総ユーザー数：",
    "Shares" : "共有数",
    "PHP" : "PHP",
    "Version:" : "バージョン:",
    "Memory Limit:" : "メモリ制限:",
    "Max Execution Time:" : "最大実行時間:",
    "Upload max size:" : "最大アップロードサイズ:",
    "Database" : "データベース",
    "Type:" : "タイプ:",
    "Size:" : "サイズ:",
    "External monitoring tool" : "外部モニタリングツール",
    "You can connect an external monitoring tool by using this end point:" : "このエンドポイントを利用して外部モニタリングツールに接続することが可能です：",
    "Did you know?" : "知ってますか？",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "URLの最後に \"?format=json\" を追加すると、JSON形式の結果が得られます。",
    "Last 24 hours" : "24時間以内",
    "Last 1 hour" : "1時間以内",
    "Last 5 mins" : "5分以内",
    "CPU load" : "CPU負荷",
    "Memory usage" : "メモリ使用量",
    "Storage" : "ストレージ",
    "Users:" : "ユーザー数:",
    "Nextcloud" : "Nextcloud",
    "Apps installed:" : "インストール済みアプリケーション：",
    "Apps updates available:" : "利用可能なアプリのアップデート："
},
"nplurals=1; plural=0;");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/ja.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU情報が利用できません",
    "Load average" : "ロードアベレージ",
    "Last minute" : "直近",
    "Memory info not available" : "メモリ情報が利用できません",
    "Total" : "合計",
    "Current usage" : "現在の利用量",
    "Users" : "ユーザー",
    "Groups" : "グループ",
    "Links" : "リンク",
    "Mails" : "メール",
    "Federated sent" : "統合送信",
    "Federated received" : "統合受信",
    "Talk conversations" : "会話",
    "24 hours" : "24時間",
    "1 hour" : "1時間",
    "5 mins" : "5分",
    "Copy" : "コピー",
    "Copied!" : "コピー完了",
    "Not supported!" : "未対応",
    "Press ⌘-C to copy." : "⌘-C でコピーします。",
    "Press Ctrl-C to copy." : "Ctrl-Cを押してコピーします。",
    "System" : "システム",
    "Monitoring" : "モニタリング",
    "Monitoring app with useful server information" : "有用なサーバー情報でアプリケーションを監視する",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "CPU負荷、メモリ使用量、ディスク使用量、ユーザー数などの役に立つサーバー情報を提供します。",
    "Operating System" : "オペレーティングシステム",
    "CPU" : "CPU",
    "Memory" : "メモリ",
    "Server time" : "サーバー時刻",
    "Uptime" : "稼働時間",
    "Time Servers" : "タイムサーバー",
    "Load" : "負荷",
    "Disk" : "ディスク",
    "Mount" : "マウント",
    "Filesystem" : "ファイルシステム",
    "Size" : "サイズ",
    "Available" : "利用可能",
    "Used" : "使用中",
    "You will get a notification once one of your disks is nearly full." : "いずれかのディスクがいっぱいになると通知を受け取ります。",
    "Files:" : "ファイル数:",
    "Storages:" : "ストレージ：",
    "Free Space:" : "空き容量：",
    "Network" : "ネットワーク",
    "Hostname" : "ホスト名",
    "DNS" : "DNS",
    "Gateway" : "ゲートウェイ",
    "Status" : "ステータス",
    "Speed" : "スピード",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "アクティブユーザー数",
    "Total users:" : "総ユーザー数：",
    "Shares" : "共有数",
    "PHP" : "PHP",
    "Version:" : "バージョン:",
    "Memory Limit:" : "メモリ制限:",
    "Max Execution Time:" : "最大実行時間:",
    "Upload max size:" : "最大アップロードサイズ:",
    "Database" : "データベース",
    "Type:" : "タイプ:",
    "Size:" : "サイズ:",
    "External monitoring tool" : "外部モニタリングツール",
    "You can connect an external monitoring tool by using this end point:" : "このエンドポイントを利用して外部モニタリングツールに接続することが可能です：",
    "Did you know?" : "知ってますか？",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "URLの最後に \"?format=json\" を追加すると、JSON形式の結果が得られます。",
    "Last 24 hours" : "24時間以内",
    "Last 1 hour" : "1時間以内",
    "Last 5 mins" : "5分以内",
    "CPU load" : "CPU負荷",
    "Memory usage" : "メモリ使用量",
    "Storage" : "ストレージ",
    "Users:" : "ユーザー数:",
    "Nextcloud" : "Nextcloud",
    "Apps installed:" : "インストール済みアプリケーション：",
    "Apps updates available:" : "利用可能なアプリのアップデート："
},
"nplurals=1; plural=0;");
